@@ -64,7 +64,6 @@ public:
         FirstPlayDate,
         LastPlayDate,
         PlayCounter,
-        PlayFrequency,
         ElementTypeRole,
         LyricsRole,
         FullDataRole,
@@ -321,6 +320,10 @@ public:
         {
             return operator[](key_type::FileModificationTime).toDateTime();
         }
+
+        [[nodiscard]] bool albumInfoIsSame(const TrackDataType &other) const;
+
+        [[nodiscard]] bool isSameTrack(const TrackDataType &other) const;
     };
 
     using ListTrackDataType = QList<TrackDataType>;
