@@ -133,8 +133,7 @@ protected:
 
     void undoChanges();
 
-    virtual void fillDataFromTrackData(const TrackMetadataModel::TrackDataType &trackData,
-                                       const QList<DataTypes::ColumnsRoles> &fieldsForTrack);
+    virtual void fillDataFromTrackData(const TrackMetadataModel::TrackDataType &trackData);
 
     virtual void fillDataForNewRadio();
 
@@ -173,6 +172,8 @@ private:
 
     void fetchLyrics();
 
+    void resetDisplayData();
+
     TrackDataType mFullData;
 
     TrackDataType mDisplayData;
